==> zio-aws-macie2_2.13-5.19.8.3-sources.jar: zio/aws/macie2/model/TestCustomDataIdentifierResponse.scala <==
package zio.aws.macie2.model
import zio.prelude.data.Optional
import zio.aws.macie2.model.primitives.__integer
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class TestCustomDataIdentifierResponse(
    matchCount: Optional[__integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse = {
    import TestCustomDataIdentifierResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
      .builder()
      .optionallyWith(matchCount.map(value => value: Integer))(_.matchCount)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly =
    zio.aws.macie2.model.TestCustomDataIdentifierResponse.wrap(buildAwsValue())
}
object TestCustomDataIdentifierResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.TestCustomDataIdentifierResponse =
      zio.aws.macie2.model
        .TestCustomDataIdentifierResponse(matchCount.map(value => value))
    def matchCount: Optional[__integer]
    def getMatchCount: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("matchCount", matchCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ) extends zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly {
    override val matchCount: Optional[__integer] = zio.aws.core.internal
      .optionalFromNullable(impl.matchCount())
      .map(value => value: __integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ): zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/TestCustomDataIdentifierResponse.scala <==
package zio.aws.macie2.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__integer
import scala.jdk.CollectionConverters.*
final case class TestCustomDataIdentifierResponse(
    matchCount: Option[__integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse = {
    import TestCustomDataIdentifierResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
      .builder()
      .optionallyWith(
        matchCount.map(value => __integer.unwrap(value): Integer)
      )(_.matchCount)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly =
    zio.aws.macie2.model.TestCustomDataIdentifierResponse.wrap(buildAwsValue())
}
object TestCustomDataIdentifierResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.TestCustomDataIdentifierResponse =
      zio.aws.macie2.model
        .TestCustomDataIdentifierResponse(matchCount.map(value => value))
    def matchCount: Option[__integer]
    def getMatchCount: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("matchCount", matchCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ) extends zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly {
    override val matchCount: Option[__integer] = scala
      .Option(impl.matchCount())
      .map(value => zio.aws.macie2.model.primitives.__integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.TestCustomDataIdentifierResponse
  ): zio.aws.macie2.model.TestCustomDataIdentifierResponse.ReadOnly =
    new Wrapper(impl)
}
